accounting

package module
v0.0.0-...-00e2eb9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 29, 2020 License: MIT Imports: 7 Imported by: 0

README

Accounting

A online banking related application focussed on transactions with different order types.

Introduction

Creating different types of lists for exchange orders by quering transactions and customer data in a PostgreSQL Database. This combination is mostly used on transactions with ATM's

The Exchange Order Types, within a transaction, are:

  • withdrawal:0
  • buy:1
  • spread:2
  • fee:3

Requirements

  • Go 1.15.x
Dependencies

Following packages are imported and need to be installed

go get -u github.com/google/uuid
go get -u github.com/imdario/mergo
go get -u github.com/stretchr/testify
go get -u gorm.io/gorm
go get -u gorm.io/datatypes
go get -u gorm.io/driver/postgres

To Do's
  • add database driver (GORM)
  • add calculations to the list for spread, fee and withdrawal

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Acc

type Acc interface {
	Create(c []models.ExchangeOrder) error
}

Acc ...

func New

func New() Acc

New ...

type Accounting

type Accounting struct {
}

Accounting ...

func (*Accounting) Create

func (acc *Accounting) Create(c []models.ExchangeOrder) error

Create ...

func (*Accounting) Init

func (acc *Accounting) Init()

Init ...

type Service

type Service struct {
	App app.App
}

Service is a struct

Directories

Path Synopsis

Jump to